diff --git a/zen/template.block-editing.inc b/zen/template.block-editing.inc
index 17d58ae..7397c14 100644
--- a/zen/template.block-editing.inc
+++ b/zen/template.block-editing.inc
@@ -12,7 +12,7 @@
  * @param $hook
  *   The name of the template being rendered ("block" in this case.)
  */
-function zen_preprocess_block_editing(&$vars, $hook) {
+function zen1_preprocess_block_editing(&$vars, $hook) {
   $block = $vars['block'];
 
   // Display 'edit block' for custom blocks.
diff --git a/zen/template.comment.inc b/zen/template.comment.inc
index 77ada2d..4e1d503 100644
--- a/zen/template.comment.inc
+++ b/zen/template.comment.inc
@@ -12,7 +12,7 @@
  * @param $hook
  *   The name of the template being rendered ("comment" in this case.)
  */
-function _zen_preprocess_comment(&$vars, $hook) {
+function _zen1_preprocess_comment(&$vars, $hook) {
   // Add an "unpublished" flag.
   $vars['unpublished'] = ($vars['comment']->status == COMMENT_NOT_PUBLISHED);
 
diff --git a/zen/template.theme-registry.inc b/zen/template.theme-registry.inc
index ca2a578..a6d55ce 100644
--- a/zen/template.theme-registry.inc
+++ b/zen/template.theme-registry.inc
@@ -9,19 +9,19 @@
  *
  * We are simply using this hook as a convenient time to do some related work.
  */
-function _zen_theme(&$existing, $type, $theme, $path) {
+function _zen1_theme(&$existing, $type, $theme, $path) {
   // Compute the conditional stylesheets.
   if (!module_exists('conditional_styles')) {
-    include_once './' . _zen_path() . '/template.conditional-styles.inc';
+    include_once './' . _zen1_path() . '/template.conditional-styles.inc';
     // _conditional_styles_theme() only needs to be run once.
-    if ($theme == 'zen') {
+    if ($theme == 'zen1') {
       _conditional_styles_theme($existing, $type, $theme, $path);
     }
   }
 
   // Since we are rebuilding the theme registry and the theme settings' default
   // values may have changed, make sure they are saved in the database properly.
-  zen_theme_get_default_settings($theme);
+  zen1_theme_get_default_settings($theme);
 
   // If we are auto-rebuilding the theme registry, warn about the feature.
   // Always display the warning in the admin section, otherwise limit to three
@@ -41,7 +41,7 @@ function _zen_theme(&$existing, $type, $theme, $path) {
  * @param $theme
  *   The name of theme.
  */
-function zen_theme_get_default_settings($theme) {
+function zen1_theme_get_default_settings($theme) {
   $themes = list_themes();
 
   // Get the default values from the .info file.
diff --git a/zen/zen.info b/zen/zen.info
deleted file mode 100644
index 9bb93e5..0000000
--- a/zen/zen.info
+++ /dev/null
@@ -1,81 +0,0 @@
-
-  ; The name and description of the theme used on the admin/build/themes page.
-name        = Zen
-description = Zen sub-themes are the ultimate starting themes for Drupal 6. Read the <a href="http://drupal.org/node/226507">online docs</a> or the included README.txt on how to create a sub-theme.
-
-  ; The screenshot used on the admin/build/themes page.
-screenshot = screenshot.png
-
-  ; "core" specifies the version of Drupal that this theme is compatible with.
-  ; "engine" specifies that this is a theme that uses the phptemplate engine,
-  ; Drupal's default theme engine. Its unlikely you will ever need to change
-  ; these, but they are required fields for a phptemplate theme.
-core   = 6.x
-engine = phptemplate
-
-  ; This section adds CSS files to your theme. The media type is specified in
-  ; the brackets. Typical CSS media types include "all", "screen", "print", and
-  ; "handheld". See http://www.w3.org/TR/CSS21/media.html#media-types for a full
-  ; list of stylesheet media types in CSS 2.1.
-  ;
-  ; You can also override any of Zen's stylesheets or any module's stylesheets,
-  ; an /extremely/ useful feature. See the excellent Drupal 6 Theme Guide at
-  ; http://drupal.org/node/171209 for more details.
-stylesheets[all][]   = html-elements.css
-stylesheets[all][]   = tabs.css
-stylesheets[all][]   = messages.css
-stylesheets[all][]   = block-editing.css
-stylesheets[all][]   = wireframes.css
-stylesheets[all][]   = zen.css
-stylesheets[print][] = print.css
-
-  ; The layout CSS files are added by Zen's template.php file (based on its
-  ; theme settings,) so we don't need to add them here. But if we did, it would
-  ; look like this:
-  ;   stylesheets[all][] = layout.css
-  ;   stylesheets[all][] = layout-liquid.css
-
-  ; Set the conditional stylesheets that are processed by IE.
-conditional-stylesheets[if IE][all][] = ie.css
-
-  ; The regions defined in Zen's default page.tpl.php file.  The name in
-  ; brackets is the name of the variable in the page.tpl.php file, (e.g.
-  ; "[content_top]" in the .info file means there should be a $content_top
-  ; variable in the page.tpl.php file.) The text after the equals sign is a
-  ; descriptive text used on the admin/build/blocks page.
-regions[left]           = left sidebar
-regions[right]          = right sidebar
-regions[navbar]         = navigation bar
-regions[content_top]    = content top
-regions[content_bottom] = content bottom
-regions[header]         = header
-regions[footer]         = footer
-regions[closure_region] = closure
-
-  ; Various page elements output by the theme can be toggled on and off. The
-  ; "features" control which of these check boxes display on the
-  ; admin/build/themes config page. This is useful for suppressing check boxes
-  ; for elements not used by your sub-theme. To suppress a check box, omit the
-  ; entry for it below. See the Drupal 6 Theme Guide for more info:
-  ; http://drupal.org/node/171205#features
-features[] = logo
-features[] = name
-features[] = slogan
-features[] = mission
-features[] = node_user_picture
-features[] = comment_user_picture
-features[] = search
-features[] = favicon
-features[] = primary_links
-features[] = secondary_links
-
-  ; Set the default settings to be used in theme-settings.php
-settings[zen_block_editing]        = 1
-settings[zen_breadcrumb]           = yes
-settings[zen_breadcrumb_separator] = ' › '
-settings[zen_breadcrumb_home]      = 1
-settings[zen_breadcrumb_trailing]  = 1
-settings[zen_breadcrumb_title]     = 0
-settings[zen_layout]               = border-politics-liquid
-settings[zen_rebuild_registry]     = 0
-settings[zen_wireframes]           = 0

diff --git a/zen/template.php b/zen/template.php
index 64cdbf8..6a4a49c 100644
--- a/zen/template.php
+++ b/zen/template.php
@@ -6,7 +6,7 @@
  * IMPORTANT WARNING: DO NOT MODIFY THIS FILE.
  *
  * The base Zen theme is designed to be easily extended by its sub-themes. You
  * shouldn't modify this or any of the CSS or PHP files in the root zen/ folder.
  * See the online documentation for more information:
  *   http://drupal.org/node/193318
  */
@@ -20,21 +20,21 @@ if (theme_get_setting('zen_rebuild_registry')) {
  * Add stylesheets only needed when Zen is the active theme. Don't do something
  * this dumb in your sub-theme; see how wireframes.css is handled instead.
  */
-if ($GLOBALS['theme'] == 'zen') { // If we're in the main theme
+if ($GLOBALS['theme'] == 'zen1') { // If we're in the main theme
   if (theme_get_setting('zen_layout') == 'border-politics-fixed') {
-    drupal_add_css(_zen_path() . '/layout-fixed.css', 'theme', 'all');
+    drupal_add_css(_zen1_path() . '/layout-fixed.css', 'theme', 'all');
   }
   else {
-    drupal_add_css(_zen_path() . '/layout-liquid.css', 'theme', 'all');
+    drupal_add_css(_zen1_path() . '/layout-liquid.css', 'theme', 'all');
   }
 }
 
 /**
  * Implements HOOK_theme().
  */
-function zen_theme(&$existing, $type, $theme, $path) {
-  include_once './' . _zen_path() . '/template.theme-registry.inc';
-  return _zen_theme($existing, $type, $theme, $path);
+function zen1_theme(&$existing, $type, $theme, $path) {
+  include_once './' . _zen1_path() . '/template.theme-registry.inc';
+  return _zen1_theme($existing, $type, $theme, $path);
 }
 
 /**
@@ -45,7 +45,7 @@ function zen_theme(&$existing, $type, $theme, $path) {
  * @return
  *   A string containing the breadcrumb output.
  */
-function zen_breadcrumb($breadcrumb) {
+function zen1_breadcrumb($breadcrumb) {
   // Determine if we are to display the breadcrumb.
   $show_breadcrumb = theme_get_setting('zen_breadcrumb');
   if ($show_breadcrumb == 'yes' || $show_breadcrumb == 'admin' && arg(0) == 'admin') {
@@ -78,7 +78,7 @@ function zen_breadcrumb($breadcrumb) {
 /**
  * Implements theme_menu_item_link()
  */
-function zen_menu_item_link($link) {
+function zen1_menu_item_link($link) {
   if (empty($link['localized_options'])) {
     $link['localized_options'] = array();
   }
@@ -95,7 +95,7 @@ function zen_menu_item_link($link) {
 /**
  * Duplicate of theme_menu_local_tasks() but adds clear-block to tabs.
  */
-function zen_menu_local_tasks() {
+function zen1_menu_local_tasks() {
   $output = '';
 
   // CTools requires a different set of local task functions.
@@ -127,7 +127,7 @@ function zen_menu_local_tasks() {
  * @param $hook
  *   The name of the template being rendered ("page" in this case.)
  */
-function zen_preprocess_page(&$vars, $hook) {
+function zen1_preprocess_page(&$vars, $hook) {
   // Add conditional stylesheets.
   if (!module_exists('conditional_styles')) {
     $vars['styles'] .= $vars['conditional_styles'] = variable_get('conditional_styles_' . $GLOBALS['theme'], '');
@@ -143,7 +143,7 @@ function zen_preprocess_page(&$vars, $hook) {
   if (!$vars['is_front']) {
     // Add unique class for each page.
     $path = drupal_get_path_alias($_GET['q']);
-    $classes[] = zen_id_safe('page-' . $path);
+    $classes[] = zen1_id_safe('page-' . $path);
     // Add unique class for each website section.
     list($section, ) = explode('/', $path, 2);
     if (arg(0) == 'node') {
@@ -154,7 +154,7 @@ function zen_preprocess_page(&$vars, $hook) {
         $section = 'node-' . arg(2);
       }
     }
-    $classes[] = zen_id_safe('section-' . $section);
+    $classes[] = zen1_id_safe('section-' . $section);
   }
   if (theme_get_setting('zen_wireframes')) {
     $classes[] = 'with-wireframes'; // Optionally add the wireframes style.
@@ -171,7 +171,7 @@ function zen_preprocess_page(&$vars, $hook) {
  * @param $hook
  *   The name of the template being rendered ("maintenance_page" in this case.)
  */
-function zen_preprocess_maintenance_page(&$vars, $hook) {
+function zen1_preprocess_maintenance_page(&$vars, $hook) {
   // Add conditional stylesheets.
   if (!module_exists('conditional_styles')) {
     $vars['styles'] .= $vars['conditional_styles'] = variable_get('conditional_styles_' . $GLOBALS['theme'], '');
@@ -190,7 +190,7 @@ function zen_preprocess_maintenance_page(&$vars, $hook) {
  * @param $hook
  *   The name of the template being rendered ("node" in this case.)
  */
-function zen_preprocess_node(&$vars, $hook) {
+function zen1_preprocess_node(&$vars, $hook) {
   // Special classes for nodes
   $classes = array('node');
   if ($vars['sticky']) {
@@ -210,7 +210,7 @@ function zen_preprocess_node(&$vars, $hook) {
     $classes[] = 'node-teaser'; // Node is displayed as teaser.
   }
   // Class for node type: "node-type-page", "node-type-story", "node-type-my-custom-type", etc.
-  $classes[] = zen_id_safe('node-type-' . $vars['type']);
+  $classes[] = zen1_id_safe('node-type-' . $vars['type']);
   $vars['classes'] = implode(' ', $classes); // Concatenate with spaces
 }
 
@@ -222,9 +222,9 @@ function zen_preprocess_node(&$vars, $hook) {
  * @param $hook
  *   The name of the template being rendered ("comment" in this case.)
  */
-function zen_preprocess_comment(&$vars, $hook) {
-  include_once './' . _zen_path() . '/template.comment.inc';
-  _zen_preprocess_comment($vars, $hook);
+function zen1_preprocess_comment(&$vars, $hook) {
+  include_once './' . _zen1_path() . '/template.comment.inc';
+  _zen1_preprocess_comment($vars, $hook);
 }
 
 /**
@@ -235,7 +235,7 @@ function zen_preprocess_comment(&$vars, $hook) {
  * @param $hook
  *   The name of the template being rendered ("block" in this case.)
  */
-function zen_preprocess_block(&$vars, $hook) {
+function zen1_preprocess_block(&$vars, $hook) {
   $block = $vars['block'];
 
   // Special classes for blocks.
@@ -249,8 +249,8 @@ function zen_preprocess_block(&$vars, $hook) {
   $vars['edit_links_array'] = array();
   $vars['edit_links'] = '';
   if (theme_get_setting('zen_block_editing') && user_access('administer blocks')) {
-    include_once './' . _zen_path() . '/template.block-editing.inc';
-    zen_preprocess_block_editing($vars, $hook);
+    include_once './' . _zen1_path() . '/template.block-editing.inc';
+    zen1_preprocess_block_editing($vars, $hook);
     $classes[] = 'with-block-editing';
   }
 
@@ -273,7 +273,7 @@ function zen_preprocess_block(&$vars, $hook) {
  * @return
  *   The converted string
  */
-function zen_id_safe($string) {
+function zen1_id_safe($string) {
   // Replace with dashes anything that isn't A-Z, numbers, dashes, or underscores.
   return strtolower(preg_replace('/[^a-zA-Z0-9-]+/', '-', $string));
 }
@@ -282,14 +282,14 @@ function zen_id_safe($string) {
  * Returns the path to the Zen theme.
  *
  * drupal_get_filename() is broken; see #341140. When that is fixed in Drupal 6,
- * replace _zen_path() with drupal_get_path('theme', 'zen').
+ * replace _zen1_path() with drupal_get_path('theme', 'zen1').
  */
-function _zen_path() {
+function _zen1_path() {
   static $path = FALSE;
   if (!$path) {
-    $matches = drupal_system_listing('zen\.info$', 'themes', 'name', 0);
-    if (!empty($matches['zen']->filename)) {
-      $path = dirname($matches['zen']->filename);
+    $matches = drupal_system_listing('zen1\.info$', 'themes', 'name', 0);
+    if (!empty($matches['zen1']->filename)) {
+      $path = dirname($matches['zen1']->filename);
     }
   }
   return $path;
@@ -6,7 +6,7 @@
  *
  * The base Zen theme is designed to be easily extended by its sub-themes. You
- * shouldn't modify this or any of the CSS or PHP files in the root zen/ folder.
+ * shouldn't modify this or any of the CSS or PHP files in the root zen1/ folder.
  * See the online documentation for more information:
  *   http://drupal.org/node/193318
diff --git a/zen/theme-settings.php b/zen/theme-settings.php
index cd07f76..42add43 100644
--- a/zen/theme-settings.php
+++ b/zen/theme-settings.php
@@ -1,6 +1,6 @@
 <?php
-// Include the definition of zen_theme_get_default_settings().
-include_once './' . drupal_get_path('theme', 'zen') . '/template.theme-registry.inc';
+// Include the definition of zen1_theme_get_default_settings().
+include_once './' . drupal_get_path('theme', 'zen1') . '/template.theme-registry.inc';
 
 
 /**
@@ -13,16 +13,16 @@ include_once './' . drupal_get_path('theme', 'zen') . '/template.theme-registry.
  * @return
  *   A form array.
  */
-function zen_settings($saved_settings, $subtheme_defaults = array()) {
+function zen1_settings($saved_settings, $subtheme_defaults = array()) {
 
   // Add the form's CSS
-  drupal_add_css(drupal_get_path('theme', 'zen') . '/theme-settings.css', 'theme');
+  drupal_add_css(drupal_get_path('theme', 'zen1') . '/theme-settings.css', 'theme');
 
   // Add javascript to show/hide optional settings
-  drupal_add_js(drupal_get_path('theme', 'zen') . '/theme-settings.js', 'theme');
+  drupal_add_js(drupal_get_path('theme', 'zen1') . '/theme-settings.js', 'theme');
 
   // Get the default values from the .info file.
-  $defaults = zen_theme_get_default_settings('zen');
+  $defaults = zen1_theme_get_default_settings('zen1');
 
   // Allow a subtheme to override the default values.
   $defaults = array_merge($defaults, $subtheme_defaults);